BluetoothData class
Constructors
- BluetoothData({required String data, required String rawData, required int bytesRead, required int timestamp, int? chunkCount, String? deviceAddress})
- BluetoothData.fromClassicDataEvent(ClassicDataEvent event)
-
Create BluetoothData from ClassicDataEvent for backward compatibility
factory
-
BluetoothData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- bytesRead → int
-
final
- chunkCount → int?
-
final
- cleanWeight → String
-
no setter
- data → String
-
final
- dateTime → DateTime
-
no setter
- deviceAddress → String?
-
final
- hasDeviceAddress → bool
-
Returns true if device address is known
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBatchedData → bool
-
Returns true if this data comes from a batched stream (has chunkCount)
no setter
- rawData → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited